/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.model.AbstractEntityManager;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public abstract class TaskManager<T extends Task> extends AbstractEntityManager<T> {

    private static final Logger LOGGER = Logger.getLogger(TaskManager.class.getCanonicalName());
    private PropertyChangeSupport support = new PropertyChangeSupport(this);
    public static final String PROP_TASK_ADDED = "taskAdded";
    public static final String TASKS_DIR_NAME = "Tasks";

    public FileObject getTaskDirectory(Project project) {
        FileObject projectDirectory = project.getProjectDirectory();
        FileObject tasksDirectory = projectDirectory.getFileObject(TASKS_DIR_NAME);
        if (tasksDirectory == null) {
            try {
                tasksDirectory = projectDirectory.createFolder(TASKS_DIR_NAME);
            } catch (IOException ex) {
                LOGGER.log(Level.WARNING, "Unable to create Task directory {0}", ex.getMessage());
            }
        }
        return tasksDirectory;
    }

    public abstract FileObject getStorageFolder(Project project);

    public void addPropertyChangeListener(PropertyChangeListener listener, String propertyName) {
        getPropertyChangeSupport().addPropertyChangeListener(propertyName, listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener, String propertyName) {
        getPropertyChangeSupport().removePropertyChangeListener(propertyName, listener);
    }

    public PropertyChangeSupport getPropertyChangeSupport() {
        return support;
    }

    public static Project findProject(AgroURI agroURI) {
        return EnterpriseIdProvider.ProjectFinder.find(agroURI);
    }
}
