/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.factory;

import java.awt.Dimension;
import java.util.List;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;

/**
 * Controller for the TaskObjectFactory selection wizard panel. 
 * 
 * @author Gerben Feenstra
 */
public class TaskObjectFactorySelectController implements WizardDescriptor.Panel<WizardDescriptor> {

    public static final String PROP_SELECTED_TASKOBJECTFACTORY = "SelectedFactory";
    
    private TaskObjectFactorySelectPanel visualPanel;
    private ASBodyPanel component;
    private List<TaskObjectFactory> supportedFactories;
    private String panelTitle;

    public TaskObjectFactorySelectController(List<TaskObjectFactory> supportedFactories, String panelTitle, String panelText, Dimension panelSize) {
        this.supportedFactories = supportedFactories;
        this.panelTitle = panelTitle;
        visualPanel = new TaskObjectFactorySelectPanel(panelText);
        visualPanel.setMinimumSize(panelSize);
        visualPanel.setPreferredSize(panelSize);
    }

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        if (component == null) {
            visualPanel.setTaskObjectFactories(supportedFactories);
            component = new ASBodyPanel(visualPanel);
            component.setName(panelTitle);
            component.setTitle(panelTitle);
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        return null;
    }

    /**
     * Used to retrieve previous panel state. Not implemented for this panel.
     *
     * @param wiz
     */
    @Override
    public void readSettings(WizardDescriptor wiz) {
    }

    /**
     * Store selected Geometricals and selected project in the wizardDescriptor
     * for retrievel after this wizard finishes.
     *
     * @param wiz
     */
    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty(PROP_SELECTED_TASKOBJECTFACTORY, visualPanel.getComboBoxModel().getSelectedItem());
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }
}
