/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.factory;

import java.util.List;
import javax.swing.*;
import net.miginfocom.swing.MigLayout;
import org.openide.util.NbBundle.Messages;

/**
 * Actual panel, part of the wizard to select a TaskObjectFactory, containing a combobox containing all specified factories.
 * @author Gerben Feenstra
 */
@Messages({
    "TaskObjectFactorySelectPanel_selectionlist_prompt=Source:"
})
public class TaskObjectFactorySelectPanel extends JPanel {

    private static final String SELECTION_LIST_PROMPT = Bundle.TaskObjectFactorySelectPanel_selectionlist_prompt();
    
    private ComboBoxModel<TaskObjectFactory> comboBoxModel = new DefaultComboBoxModel<TaskObjectFactory>();
    private JComboBox factoryComboBox;
    private JLabel caption;
    private JLabel selectionListPrompt;

    public TaskObjectFactorySelectPanel(String panelText) {
        // Set layout
        this.setLayout(new MigLayout("wrap 2"));

        // Create combobox
        factoryComboBox = new JComboBox();
        factoryComboBox.setModel(comboBoxModel);

        // Create caption Text
        caption = new JLabel(panelText);
        selectionListPrompt = new JLabel(SELECTION_LIST_PROMPT);
        this.add(caption, "span");
        this.add(selectionListPrompt);
        this.add(factoryComboBox);
    }

    public ComboBoxModel<TaskObjectFactory> getComboBoxModel() {
        return comboBoxModel;
    }

    public void setTaskObjectFactories(List<TaskObjectFactory> factories){
        for(TaskObjectFactory factory : factories){
            factoryComboBox.addItem(factory);
        }
    }
}
