/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.task.windows;

import java.awt.Color;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JLabel;
import nl.cloudfarming.client.task.Task;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class TaskStatePanel extends javax.swing.JPanel {

    public TaskStatePanel() {
        initComponents();
        setBackground(Color.WHITE);
    }

    /**
     * Creates new form TaskStatePanel
     */
    public TaskStatePanel(final Task task) {
        this();
        setTask(task);
    }

    public void setTask(final Task task) {
        task.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if (Task.PROP_STATUS.equals(evt.getPropertyName())) {
                    updateStatus(task);
                }
            }
        });
        updateStatus(task);

    }

    private void updateStatus(Task task) {
        if (task.isComplete()) {
            stateValue.setForeground(Color.GREEN);
            stateValue.setText("complete");
        } else {
            stateValue.setForeground(Color.RED);
            stateValue.setText("incomplete");
        }
    }

    public JLabel getStateValue() {
        return stateValue;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        stateLabel = new javax.swing.JLabel();
        stateValue = new javax.swing.JLabel();

        org.openide.awt.Mnemonics.setLocalizedText(stateLabel, org.openide.util.NbBundle.getMessage(TaskStatePanel.class, "TaskStatePanel.stateLabel.text")); // NOI18N

        org.openide.awt.Mnemonics.setLocalizedText(stateValue, org.openide.util.NbBundle.getMessage(TaskStatePanel.class, "TaskStatePanel.stateValue.text")); // NOI18N

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(stateLabel)
                .addGap(18, 18, 18)
                .addComponent(stateValue, javax.swing.GroupLayout.PREFERRED_SIZE, 122, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(stateLabel)
                    .addComponent(stateValue))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel stateLabel;
    private javax.swing.JLabel stateValue;
    // End of variables declaration//GEN-END:variables
}
